Motion

Struct Motion 

pub struct Motion<T> { /* private fields */ }
A typed handle to an animation stored in a MotionRuntime.

Handles become invalid after their animation is removed.

Implementations

Source

impl<T> Motion<T>
where T: Animatable,

pub fn transition_to(self, target: T, runtime: &mut MotionRuntime) -> bool

Transitions this motion toward target.

Returns false when the handle is no longer valid.

pub fn play( self, animation: impl Animation<T>, runtime: &mut MotionRuntime, ) -> bool

Replaces this motion’s current animation.

Returns false when the handle is no longer valid.

pub fn value(self, runtime: &MotionRuntime) -> T

Clones and returns the current value.

Panics

Panics when the handle is no longer valid.

pub fn value_ref(self, runtime: &MotionRuntime) -> &T

Borrows the current value.

Panics

Panics when the handle is no longer valid.

pub fn try_value(self, runtime: &MotionRuntime) -> Option<&T>

Borrows the current value when the handle is valid.

pub fn state(self, runtime: &MotionRuntime) -> Option<AnimationState>

Returns the current state when the handle is valid.

pub fn is_active(self, runtime: &MotionRuntime) -> bool

Returns whether the motion is active.

pub fn is_completed(self, runtime: &MotionRuntime) -> bool

Returns whether the motion completed.

pub fn pause(self, runtime: &mut MotionRuntime) -> bool

Pauses the motion if the handle is valid.

pub fn resume(self, runtime: &mut MotionRuntime) -> bool

Resumes the motion if the handle is valid.

pub fn cancel(self, runtime: &mut MotionRuntime) -> bool

Cancels the motion if the handle is valid.

pub fn seek(self, progress: f32, runtime: &mut MotionRuntime) -> bool

Seeks the motion to normalized progress if the handle is valid.

pub fn finish(self, runtime: &mut MotionRuntime) -> bool

Moves the motion to completion if the handle is valid.

pub fn remove(self, runtime: &mut MotionRuntime) -> bool

Removes the motion from the runtime.