pub struct Presence<T>where
T: Animatable,{ /* private fields */ }Expand description
Coordinates mounting and visibility around enter and exit animations.
Examples
use aura_anim_core::{MotionRuntime, Presence, timing::Timing};
use std::time::Duration;
let mut runtime = MotionRuntime::new();
let mut presence = Presence::new(&mut runtime, 0.0_f32, 1.0, Timing::new(100.0));
presence.show(&mut runtime);
assert!(presence.is_mounted());
runtime.tick(Duration::from_millis(100));
assert_eq!(*presence.value(&runtime), 1.0);
presence.hide(&mut runtime);
runtime.tick(Duration::from_millis(100));
presence.sync(&runtime);
assert!(!presence.is_mounted());Implementations
Sourceimpl<T> Presence<T>where
T: Animatable,
impl<T> Presence<T>where
T: Animatable,
Sourcepub fn new(
runtime: &mut MotionRuntime,
hidden: T,
visible: T,
timing: Timing,
) -> Presence<T>
pub fn new( runtime: &mut MotionRuntime, hidden: T, visible: T, timing: Timing, ) -> Presence<T>
Creates a hidden, unmounted presence controller.
Sourcepub fn motion(&self) -> Motion<T>
pub fn motion(&self) -> Motion<T>
Returns the runtime motion controlled by this presence value.
Sourcepub fn value<'a>(&self, runtime: &'a MotionRuntime) -> &'a T
pub fn value<'a>(&self, runtime: &'a MotionRuntime) -> &'a T
Returns the current animated value.
Sourcepub const fn is_mounted(&self) -> bool
pub const fn is_mounted(&self) -> bool
Returns whether the associated content should be mounted.
Sourcepub const fn is_visible(&self) -> bool
pub const fn is_visible(&self) -> bool
Returns whether the presence target is visible.
Sourcepub fn show(&mut self, runtime: &mut MotionRuntime)
pub fn show(&mut self, runtime: &mut MotionRuntime)
Mounts the content and transitions toward the visible value.
Sourcepub fn hide(&mut self, runtime: &mut MotionRuntime)
pub fn hide(&mut self, runtime: &mut MotionRuntime)
Transitions toward the hidden value.
Sourcepub fn show_with(
&mut self,
animation: impl Animation<T>,
runtime: &mut MotionRuntime,
)
pub fn show_with( &mut self, animation: impl Animation<T>, runtime: &mut MotionRuntime, )
Mounts the content and plays a custom enter animation.
Sourcepub fn hide_with(
&mut self,
animation: impl Animation<T>,
runtime: &mut MotionRuntime,
)
pub fn hide_with( &mut self, animation: impl Animation<T>, runtime: &mut MotionRuntime, )
Plays a custom exit animation.
Sourcepub fn sync(&mut self, runtime: &MotionRuntime)
pub fn sync(&mut self, runtime: &MotionRuntime)
Unmounts hidden content after its animation completes.