pub struct Tween<T>where
T: Animatable,{ /* private fields */ }Expand description
An animation that interpolates between two values using Timing.
Examples
use aura_anim_core::{Tween, timing::Timing};
use std::time::Duration;
let mut tween = Tween::between(0.0_f32, 10.0, Timing::new(100.0));
tween.tick(Duration::from_millis(50));
assert_eq!(*tween.value(), 5.0);
tween.tick(Duration::from_millis(50));
assert!(tween.is_completed());
assert_eq!(*tween.value(), 10.0);Implementations
Sourceimpl<T> Tween<T>where
T: Animatable,
impl<T> Tween<T>where
T: Animatable,
Sourcepub fn new(value: T) -> Tween<T>
pub fn new(value: T) -> Tween<T>
Creates an idle tween with the default 200 millisecond timing.
Sourcepub fn with_timing(value: T, timing: Timing) -> Tween<T>
pub fn with_timing(value: T, timing: Timing) -> Tween<T>
Creates an idle tween with the provided timing.
Sourcepub fn between(from: T, to: T, timing: Timing) -> Tween<T>
pub fn between(from: T, to: T, timing: Timing) -> Tween<T>
Creates a running tween from from to to.
Sourcepub const fn state(&self) -> AnimationState
pub const fn state(&self) -> AnimationState
Returns the current lifecycle state.
Sourcepub fn is_completed(&self) -> bool
pub fn is_completed(&self) -> bool
Returns whether the tween has completed.
Sourcepub fn transition_to(&mut self, target: T)
pub fn transition_to(&mut self, target: T)
Starts a transition from the current value to target.