pub struct MotionEvent { /* private fields */ }Expand description
A structured runtime lifecycle event.
Implementations
Sourceimpl MotionEvent
impl MotionEvent
Sourcepub const fn playback(self) -> PlaybackId
pub const fn playback(self) -> PlaybackId
Returns the concrete playback associated with this event.
Sourcepub const fn kind(self) -> MotionEventKind
pub const fn kind(self) -> MotionEventKind
Returns the event kind.
Sourcepub fn is_for(self, target: impl MotionEventTarget) -> bool
pub fn is_for(self, target: impl MotionEventTarget) -> bool
Returns whether this event belongs to target.
Sourcepub fn is_completed_for(self, target: impl MotionEventTarget) -> bool
pub fn is_completed_for(self, target: impl MotionEventTarget) -> bool
Returns whether this is a completed event for target.
Sourcepub fn is_canceled_for(self, target: impl MotionEventTarget) -> bool
pub fn is_canceled_for(self, target: impl MotionEventTarget) -> bool
Returns whether this is a canceled event for target.