Presence

Struct Presence 

pub struct Presence<T>
where T: Animatable,
{ /* private fields */ }
Coordinates mounting and visibility around enter and exit animations.

Examples

use aura_anim_core::{MotionRuntime, Presence, timing::Timing};
use std::time::Duration;

let mut runtime = MotionRuntime::new();
let mut presence = Presence::new(&mut runtime, 0.0_f32, 1.0, Timing::new(100.0));

presence.show(&mut runtime);
assert!(presence.is_mounted());
runtime.tick(Duration::from_millis(100));
assert_eq!(*presence.value(&runtime), 1.0);

presence.hide(&mut runtime);
runtime.tick(Duration::from_millis(100));
presence.sync(&runtime);
assert!(!presence.is_mounted());

Implementations

Source

impl<T> Presence<T>
where T: Animatable,

pub fn new( runtime: &mut MotionRuntime, hidden: T, visible: T, timing: Timing, ) -> Presence<T>

Creates a hidden, unmounted presence controller.

pub fn motion(&self) -> Motion<T>

Returns the runtime motion controlled by this presence value.

pub fn value<'a>(&self, runtime: &'a MotionRuntime) -> &'a T

Returns the current animated value.

pub const fn is_mounted(&self) -> bool

Returns whether the associated content should be mounted.

pub const fn is_visible(&self) -> bool

Returns whether the presence target is visible.

pub fn show(&mut self, runtime: &mut MotionRuntime)

Mounts the content and transitions toward the visible value.

pub fn hide(&mut self, runtime: &mut MotionRuntime)

Transitions toward the hidden value.

pub fn show_with( &mut self, animation: impl Animation<T>, runtime: &mut MotionRuntime, )

Mounts the content and plays a custom enter animation.

pub fn hide_with( &mut self, animation: impl Animation<T>, runtime: &mut MotionRuntime, )

Plays a custom exit animation.

pub fn sync(&mut self, runtime: &MotionRuntime)

Unmounts hidden content after its animation completes.